*FROM: http://www.ats.ucla.edu/stat/sas/dae/ologit.htm;
* Generic session options - set page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=150 formdlim='-';											
* Kill default titles on output; 
TITLE; *ODS GRAPHICS ON; *ODS LISTING;

* Location for files to be saved - CHANGE PATH;
%LET example= F:\13_Psyc930Generalized\930_Download_Part1; 
LIBNAME example "&example.";

* Import data into work library and center/recode predictors;
DATA work.gradplan; SET example.ologit;
	parentGD = pared;
	GPA3 = GPA-3;
	     IF public=1 THEN private=0; 
	ELSE IF public=0 THEN private=1;
	ELSE IF public=. THEN private=.;
	LABEL apply=	"apply: 0=Not, 1=Eh, 2=Very"
		  parentGD= "parentGD: Parent Has Graduate Degree (0=N,1=Y)"
		  private= 	"private: Student Attends Private University (0=N,1=Y)"
		  GPA3= 	"GPA3: Student GPA (0=3)";  
RUN;
* Creating formats for binary and ordinal models;
PROC FORMAT; 
	VALUE F3apply 0="0No" 1="1Maybe" 2="2Yes";
	VALUE F2apply 0="0No" 1="1Pry"   2="1Pry";
	VALUE FparentGD 0="0NoDegree" 1="1YesDegree";
	VALUE Fprivate  0="0public" 1="1private";
RUN;

TITLE1 "DESCRIPTIVES FOR STUDY VARIABLES";
PROC MEANS DATA=work.gradplan; 
	VAR GPA apply; 
RUN;
PROC FREQ DATA=work.gradplan;
	FORMAT apply F3apply. parentGD FparentGD. private Fprivate.;
	TABLE apply parentGD private; 
RUN; TITLE1;

***** BINARY MODELS;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\1_Binary_Models.txt" 
			 LOG=  "&example.\1_Binary_Models.txt"; RUN;

TITLE1 "EMPTY MODEL PREDICTING BINARY DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 2-category apply UP via DESCENDING option;
  FORMAT apply F2apply.;
  MODEL apply (DESCENDING) = / SOLUTION LINK=LOGIT DIST=BINARY;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MODEL PREDICTING BINARY DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 2-category apply UP via DESCENDING option;
  FORMAT apply F2apply. parentGD FparentGD. private Fprivate.;
  CLASS parentGD private;
  MODEL apply (DESCENDING) = parentGD|private GPA3 / SOLUTION LINK=LOGIT DIST=BINARY;
  LSMEANS parentGD / ILINK AT(GPA3)=(-1) CL PLOTS=MEANPLOT(ILINK) DIFF=ALL; * At GPA=2;
  LSMEANS parentGD / ILINK AT(GPA3)=( 0) CL PLOTS=MEANPLOT(ILINK) DIFF=ALL; * At GPA=3;
  LSMEANS parentGD / ILINK AT(GPA3)=( 1) CL PLOTS=MEANPLOT(ILINK) DIFF=ALL; * At GPA=4;
  CONTRAST "DF=2 Wald Test for adding 3 fixed effects" parentGD -1 1, private -1 1 / CHISQ;
  ODS OUTPUT LSMeans=MeanSave;
RUN; TITLE1; 

TITLE1 "INTERACTIONS MODEL PREDICTING BINARY DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 2-category apply UP via DESCENDING option;
  FORMAT Apply F2apply. parentGD FparentGD. private Fprivate.;
  CLASS parentGD private;
  MODEL apply (DESCENDING) = parentGD|private|GPA3@2 / SOLUTION LINK=LOGIT DIST=BINARY;
  LSMEANS parentGD|private / ILINK PLOTS=MEANPLOT(ILINK) SLICEDIFF=parentGD SLICEDIFF=private AT(GPA3)=(0); * At GPA=1;
  ESTIMATE "GPA Slope for No  Degree Public School"	 GPA3 1 GPA3*parentGD 1 0 GPA3*private 1 0;
  ESTIMATE "GPA Slope for Yes Degree Public School"  GPA3 1 GPA3*parentGD 0 1 GPA3*private 1 0;
  ESTIMATE "GPA Slope for No  Degree Private School" GPA3 1 GPA3*parentGD 1 0 GPA3*private 0 1;
  ESTIMATE "GPA Slope for Yes Degree Private School" GPA3 1 GPA3*parentGD 0 1 GPA3*private 0 1;
  LSMESTIMATE parentGD "Marginal Main Effect of Parent Degree at GPA=2" -1 1 / AT(GPA3)=(-1);
  LSMESTIMATE parentGD "Marginal Main Effect of Parent Degree at GPA=3" -1 1 / AT(GPA3)=( 0);
  LSMESTIMATE parentGD "Marginal Main Effect of Parent Degree at GPA=4" -1 1 / AT(GPA3)=( 1);
RUN; TITLE1; 

* Close output;
PROC PRINTTO; RUN; ODS HTML CLOSE; ODS HTML;


***** CATEGORICAL MODELS;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\1_Categorical_Models.txt" 
			 LOG=  "&example.\1_Categorical_Models.txt"; RUN;

TITLE1 "EMPTY MODEL PREDICTING THREE-CATEGORY ORDINAL DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 3-category apply UP via DESCENDING option;
  FORMAT apply F3apply.;
  MODEL apply (DESCENDING) = / SOLUTION LINK=CLOGIT DIST=MULT;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MODEL PREDICTING THREE-CATEGORY ORDINAL DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 3-category apply UP via DESCENDING option;
  FORMAT apply F3apply. parentGD FparentGD. private Fprivate.;
  CLASS parentGD private;
  MODEL apply (DESCENDING) = parentGD private GPA3 / SOLUTION LINK=CLOGIT DIST=MULT;
  CONTRAST "DF=3 Wald Test for adding 3 fixed effects" parentGD -1 1, private -1 1, GPA3 1 / CHISQ;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MODEL PREDICTING THREE-CATEGORY ORDINAL DV";
TITLE2 "USING PROC LOGISTIC TO GET SCORE TEST";
PROC LOGISTIC DATA=work.gradplan DESCENDING; 
* Predicting 3-category apply UP via DESCENDING option;
  FORMAT apply F3apply. parentGD FparentGD. private Fprivate.;
  MODEL apply = parentGD private gpa3 / LINK=CLOGIT TECHNIQUE=NR;
RUN; TITLE1; TITLE2;

TITLE1 "MAIN EFFECTS MODEL PREDICTING THREE-CATEGORY ORDINAL PROPORTIONAL ODDS DV";
PROC NLMIXED DATA=work.gradplan METHOD=GAUSS TECH=NEWRAP; 
* Provide all estimated parameters with start values;
  PARMS B01=0.4 B02=-0.7 Bpar=0 Bpri=0 Bgpa=0;
* Linear predictive model;
  Y1 = B01 + Bpar*parentGD + Bpri*private + Bgpa*gpa3;
  Y2 = B02 + Bpar*parentGD + Bpri*private + Bgpa*gpa3;
	* Model for probability of response - writing it the shorter way;
	     IF (apply=0) THEN P =  1 - (1/(1 + EXP(-Y1)));
	ELSE IF (apply=1) THEN P =      (1/(1 + EXP(-Y1))) - (1/(1 + EXP(-Y2)));
	ELSE IF (apply=2) THEN P =                           (1/(1 + EXP(-Y2)));
	LL = LOG(P);
	MODEL apply ~ GENERAL(LL);
	CONTRAST "DF=3 Wald Test for adding 3 fixed effects" Bpar*1, Bpri*1, Bgpa*1 DF=392;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MODEL PREDICTING THREE-CATEGORY ORDINAL NON-PROPORTIONAL ODDS DV";
PROC NLMIXED DATA=work.gradplan METHOD=GAUSS TECH=NEWRAP; 
* Provide all estimated parameters with start values;
  PARMS B01=0.4 B02=-0.7 Bpar1=0 Bpar2=0 Bpri1=0 Bpri2=0 Bgpa1=0 Bgpa2=0;
* Linear predictive model;
  Y1 = B01 + Bpar1*parentGD + Bpri1*private + Bgpa1*gpa3;
  Y2 = B02 + Bpar2*parentGD + Bpri2*private + Bgpa2*gpa3;
	* Model for probability of response - writing it the shorter way;
	     IF (apply=0) THEN P =  1 - (1/(1 + EXP(-Y1)));
	ELSE IF (apply=1) THEN P =      (1/(1 + EXP(-Y1))) - (1/(1 + EXP(-Y2)));
	ELSE IF (apply=2) THEN P =                           (1/(1 + EXP(-Y2)));
	LL = LOG(P);
	MODEL apply ~ GENERAL(LL);
    CONTRAST "DF=1 Wald Test for PARENT"  Bpar1*1+Bpar2*-1 DF=392;
	CONTRAST "DF=1 Wald Test for PRIVATE" Bpri1*1+Bpri2*-1 DF=392;
	CONTRAST "DF=1 Wald Test for GPA"     Bgpa1*1+Bgpa2*-1 DF=392;
	CONTRAST "DF=6 Wald Test for adding 6 fixed effects for both" Bpar1*1, Bpri1*1, Bgpa1*1, Bpar2*1, Bpri2*1, Bgpa2*1  DF=392;
	CONTRAST "DF=3 Wald Test for proportional odds"               Bpar1*1+Bpar2*-1, Bpri1*1+Bpri2*-1, Bgpa1*1+Bgpa2*-1  DF=392;
RUN; TITLE1; 

TITLE1 "MAIN EFFECTS MODEL PREDICTING THREE-CATEGORY ORDINAL NON-PROPORTIONAL ODDS DV";
TITLE2 "Custom Model Completed in Class!";
PROC NLMIXED DATA=work.gradplan METHOD=GAUSS TECH=NEWRAP; 
* Provide all estimated parameters with start values;
  PARMS B01=0.4 B02=-0.7 Bpar=0 Bpri1=0 Bpri2=0 Bgpa=0;
* Linear predictive model;
  Y1 = B01 + Bpar*parentGD + Bpri1*private + Bgpa*gpa3;
  Y2 = B02 + Bpar*parentGD + Bpri2*private + Bgpa*gpa3;
	* Model for probability of response - writing it the shorter way;
	     IF (apply=0) THEN P =  1 - (1/(1 + EXP(-Y1)));
	ELSE IF (apply=1) THEN P =      (1/(1 + EXP(-Y1))) - (1/(1 + EXP(-Y2)));
	ELSE IF (apply=2) THEN P =                           (1/(1 + EXP(-Y2)));
	LL = LOG(P);
	MODEL apply ~ GENERAL(LL);
	CONTRAST "DF=1 Wald Test for PRIVATE" Bpri1*1+Bpri2*-1 DF=394;
	CONTRAST "DF=2 Wald Test for PRIVATE" Bpri1*1+Bpri2*1 DF=394;
	CONTRAST "DF=4 Wald Test for adding 4 fixed effects for both" Bpar*1, Bpri1*1, Bgpa*1, Bpri2*1 DF=394;
RUN; TITLE1; TITLE2;

TITLE1 "MAIN EFFECTS MODEL PREDICTING THREE-CATEGORY NOMINAL DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 3-category apply UP via DESCENDING option;
  FORMAT Apply F3apply. parentGD FparentGD. private Fprivate.;
  CLASS parentGD private;
  MODEL apply (DESCENDING) = parentGD private GPA3 / SOLUTION LINK=GLOGIT DIST=MULT;
  CONTRAST "DF=3 Wald Test for adding 3*2 fixed effects" parentGD -1 1, private -1 1, GPA3 1 / CHISQ BYCAT DF=392;
  CONTRAST "DF=6 Wald Test for adding 3 fixed effects"   parentGD -1 1, private -1 1, GPA3 1 / CHISQ DF=392;
  ESTIMATE "Intercept" intercept 1 / ILINK BYCAT;
RUN; TITLE1; 

**** New example using binomial;

TITLE1 "EMPTY MODEL PREDICTING THREE-CATEGORY ORDINAL AS BINOMIAL DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 3-category apply;
  FORMAT apply F3apply.;
  MODEL apply = / SOLUTION LINK=LOGIT DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "MAIN MODEL PREDICTING THREE-CATEGORY ORDINAL AS BINOMIAL DV";
PROC GLIMMIX DATA=work.gradplan NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
* Predicting 3-category apply;
  FORMAT Apply F3apply. parentGD FparentGD. private Fprivate.;
  CLASS parentGD private;
  MODEL apply = parentGD private GPA3 / SOLUTION LINK=LOGIT DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
  CONTRAST "DF=3 Wald Test for adding 3 fixed effects" parentGD -1 1, private -1 1, GPA3 1 / CHISQ;
RUN; TITLE1; 

* Close output;
PROC PRINTTO; RUN; ODS HTML CLOSE; ODS HTML;




