* Output options: all can be turned on/off by adding or removing the 'NO':
  page number, date, centering, or page breaks, page length and width;
OPTIONS Spool NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=120;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF; ODS GRAPHICS ON; ODS HTML CLOSE; ODS HTML;

* Location for files to be saved - CHANGE PATH;
%LET example= F:\13_Psyc930Generalized\930_Download_Part1; 
LIBNAME example "&example.";

* Import data;
PROC IMPORT DATAFILE="&example.\lesaMA.sav" OUT=work.MA DBMS=sav REPLACE; RUN;

* Get descriptives for age;
PROC MEANS DATA=MA; CLASS agegroup; VAR age; RUN;

* Recode variables;
DATA work.MA; SET work.MA; 
	* Remove formats;
	FORMAT _ALL_;
	* Remove cases with missing data on predictors;
	IF NMISS(age,gender)>0 THEN DELETE;
	* Rename gender to be interpretable;
	female = gender;
	* Create piecewise age slopes;
	     IF agegroup=0 THEN over75=0;
	ELSE IF agegroup=1 THEN over75=age-75;
	LABEL female= "0=M, 1=F" 
          over75= "Years over 75";
	* Get count of possible trials for binomial;
	Ntrials = N(OF error1--error80);
	* Get number of errors;
	Nerror = SUM(OF error1--error80);
	* Get number correct;
	Ncorrect = Ntrials - Nerror;
	* Proportion correct for comparison with predictions;
	Pcorrect = Ncorrect/Ntrials;
	* Trick into fitting a beta by removing 0s and 1s;
	Bcorrect = (Pcorrect + .01)*.98;
RUN;

* Distribution of number correct and accuracy;
PROC UNIVARIATE DATA=work.MA; 
	VAR Ncorrect Pcorrect Bcorrect; HISTOGRAM Ncorrect Pcorrect Bcorrect; 
RUN;

***** LOGIT BINOMIAL UNIVARIATE MODELS;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\1_Logit_Binomial_Univariate_Models.txt" 
			 LOG=  "&example.\1_Logit_Binomial_Univariate_Models.txt"; 
RUN;

TITLE1 "EMPTY MODEL PREDICTING BINOMIAL DV, LOGIT LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Ncorrect/Ntrials = / SOLUTION LINK=LOGIT DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "AGE PIECEWISE LINEAR MODEL PREDICTING BINOMIAL DV, LOGIT LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Ncorrect/Ntrials = agegroup over75 / SOLUTION LINK=LOGIT DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 / ILINK;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 / ILINK;
  CONTRAST "DF=2 Total Age Effect"  agegroup 1, over75 1 / CHISQ;
  OUTPUT OUT=Age PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Linear Effect of Age";
PROC GPLOT DATA=Age; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age; VAR Pcorrect PredCorrect; RUN; TITLE1;

TITLE1 "AGE PIECEWISE QUADRATIC MODEL PREDICTING BINOMIAL DV, LOGIT LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Ncorrect/Ntrials = agegroup over75 over75*over75 / SOLUTION LINK=LOGIT DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 over75*over75 -25 / ILINK CL;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 over75*over75  25 / ILINK CL;
  CONTRAST "DF=2 Over 75 Age Effect"  over75 1, over75*over75 1 / CHISQ;
  ESTIMATE "Linear Age Slope at 70"	over75 1 over75*over75 -10; * twice quad is how linear changes;
  ESTIMATE "Linear Age Slope at 75"	over75 1 over75*over75   0;
  ESTIMATE "Linear Age Slope at 80"	over75 1 over75*over75  10;
  OUTPUT OUT=Age2 PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Quadratic Effect of Age";
PROC GPLOT DATA=Age2; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age2; VAR Pcorrect PredCorrect; RUN; TITLE1;

* Close output;
PROC PRINTTO; RUN; ODS HTML CLOSE; ODS HTML;


***** LOG-LOG BINOMIAL UNIVARIATE MODELS;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\1_LogLog_Binomial_Univariate_Models.txt" 
			 LOG=  "&example.\1_LogLog_Binomial_Univariate_Models.txt"; 
RUN;

TITLE1 "EMPTY MODEL PREDICTING BINOMIAL DV, LOG-LOG LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Ncorrect/Ntrials = / SOLUTION LINK=LOGLOG DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1;

TITLE1 "AGE PIECEWISE LINEAR MODEL PREDICTING BINOMIAL DV, LOG-LOG LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Ncorrect/Ntrials = agegroup over75 / SOLUTION LINK=LOGLOG DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 / ILINK;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 / ILINK;
  CONTRAST "DF=2 Total Age Effect"  agegroup 1, over75 1 / CHISQ;
  OUTPUT OUT=Age PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Linear Effect of Age";
PROC GPLOT DATA=Age; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age; VAR Pcorrect PredCorrect; RUN; TITLE1;

TITLE1 "AGE PIECEWISE QUADRATIC MODEL PREDICTING BINOMIAL DV, LOG-LOG LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Ncorrect/Ntrials = agegroup over75 over75*over75 / SOLUTION LINK=LOGLOG DIST=BINOMIAL;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 over75*over75 -25 / ILINK CL;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 over75*over75  25 / ILINK CL;
  CONTRAST "DF=2 Over 75 Age Effect"  over75 1, over75*over75 1 / CHISQ;
  ESTIMATE "Linear Age Slope at 70"	over75 1 over75*over75 -10; * twice quad is how linear changes;
  ESTIMATE "Linear Age Slope at 75"	over75 1 over75*over75   0;
  ESTIMATE "Linear Age Slope at 80"	over75 1 over75*over75  10;
  OUTPUT OUT=Age2 PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Quadratic Effect of Age";
PROC GPLOT DATA=Age2; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age2; VAR Pcorrect PredCorrect; RUN; TITLE1;

* Close output;
PROC PRINTTO; RUN; ODS HTML CLOSE; ODS HTML;


***** LOGIT BETA UNIVARIATE MODELS;

* Distribution of beta accuracy;
PROC UNIVARIATE DATA=work.MA; 
	VAR Bcorrect; HISTOGRAM Bcorrect / BETA(ALPHA=est BETA=est); 
RUN;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\1_Logit_Beta_Univariate_Models.txt" 
			 LOG=  "&example.\1_Logit_Beta_Univariate_Models.txt"; 
RUN;

TITLE1 "EMPTY MODEL PREDICTING BETA DV, LOGIT LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Bcorrect = / SOLUTION LINK=LOGIT DIST=BETA;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "AGE PIECEWISE LINEAR MODEL PREDICTING BETA DV, LOGIT LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Bcorrect = agegroup over75 / SOLUTION LINK=LOGIT DIST=BETA;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 / ILINK;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 / ILINK;
  CONTRAST "DF=2 Total Age Effect"  agegroup 1, over75 1 / CHISQ;
  OUTPUT OUT=Age PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Linear Effect of Age";
PROC GPLOT DATA=Age; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age; VAR Pcorrect PredCorrect; RUN; TITLE1;

TITLE1 "AGE PIECEWISE QUADRATIC MODEL PREDICTING BETA DV, LOGIT LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Bcorrect = agegroup over75 over75*over75 / SOLUTION LINK=LOGIT DIST=BETA;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 over75*over75 -25 / ILINK CL;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 over75*over75  25 / ILINK CL;
  CONTRAST "DF=2 Over 75 Age Effect"  over75 1, over75*over75 1 / CHISQ;
  ESTIMATE "Linear Age Slope at 70"	over75 1 over75*over75 -10; * twice quad is how linear changes;
  ESTIMATE "Linear Age Slope at 75"	over75 1 over75*over75   0;
  ESTIMATE "Linear Age Slope at 80"	over75 1 over75*over75  10;
  OUTPUT OUT=Age2 PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Quadratic Effect of Age";
PROC GPLOT DATA=Age2; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age2;  VAR Pcorrect PredCorrect; RUN; TITLE1;

* Close output;
PROC PRINTTO; RUN; ODS HTML CLOSE; ODS HTML;


***** LOG-LOG BETA UNIVARIATE MODELS;

* Distribution of beta accuracy;
PROC UNIVARIATE DATA=work.MA; 
	VAR Bcorrect; HISTOGRAM Bcorrect / BETA(ALPHA=est BETA=est); 
RUN;

* Save SAS syntax and output to permanent text file;
PROC PRINTTO PRINT="&example.\1_LogLog_Beta_Univariate_Models.txt" 
			 LOG=  "&example.\1_LogLog_Beta_Univariate_Models.txt"; 
RUN;

TITLE1 "EMPTY MODEL PREDICTING BETA DV, LOG-LOG LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Bcorrect = / SOLUTION LINK=LOGLOG DIST=BETA;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept" intercept 1 / ILINK;
RUN; TITLE1; 

TITLE1 "AGE PIECEWISE LINEAR MODEL PREDICTING BETA DV, LOG-LOG LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Bcorrect = agegroup over75 / SOLUTION LINK=LOGLOG DIST=BETA;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 / ILINK;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 / ILINK;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 / ILINK;
  CONTRAST "DF=2 Total Age Effect"  agegroup 1, over75 1 / CHISQ;
  OUTPUT OUT=Age PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Linear Effect of Age";
PROC GPLOT DATA=Age; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age; VAR Pcorrect PredCorrect; RUN; TITLE1;

TITLE1 "AGE PIECEWISE QUADRATIC MODEL PREDICTING BETA DV, LOG-LOG LINK";
PROC GLIMMIX DATA=work.MA NOCLPRINT NOITPRINT GRADIENT METHOD=QUAD; 
  MODEL Bcorrect = agegroup over75 over75*over75 / SOLUTION LINK=LOGLOG DIST=BETA;
* Requesting logit intercept to be transformed into probability;
  ESTIMATE "Intercept for YA"       intercept 1 agegroup 0 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age70" intercept 1 agegroup 1 over75 -5 over75*over75 -25 / ILINK CL;
  ESTIMATE "Intercept for OA Age75" intercept 1 agegroup 1 over75  0 over75*over75   0 / ILINK CL;
  ESTIMATE "Intercept for OA Age80" intercept 1 agegroup 1 over75  5 over75*over75  25 / ILINK CL;
  CONTRAST "DF=2 Over 75 Age Effect"  over75 1, over75*over75 1 / CHISQ;
  ESTIMATE "Linear Age Slope at 70"	over75 1 over75*over75 -10; * twice quad is how linear changes;
  ESTIMATE "Linear Age Slope at 75"	over75 1 over75*over75   0;
  ESTIMATE "Linear Age Slope at 80"	over75 1 over75*over75  10;
  OUTPUT OUT=Age2 PRED(ILINK)=PredCorrect;
RUN; TITLE1; 

TITLE1 "Prediction by Piecewise Quadratic Effect of Age";
PROC GPLOT DATA=Age2; PLOT Pcorrect*PredCorrect; RUN; QUIT; 
PROC CORR DATA=Age2;  VAR Pcorrect PredCorrect; RUN; TITLE1;

* Close output;
PROC PRINTTO; RUN; ODS HTML CLOSE; ODS HTML;
